==> lib32-libevent-2.1.12-2-x86_64.pkg.tar.zst: usr/lib32/cmake/libevent/LibeventTargets-shared-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "libevent::core" for configuration "None"
set_property(TARGET libevent::core APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(libevent::core PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib32/libevent_core-2.1.so.7.0.1"
  IMPORTED_SONAME_NONE "libevent_core-2.1.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS libevent::core )
list(APPEND _IMPORT_CHECK_FILES_FOR_libevent::core "${_IMPORT_PREFIX}/lib32/libevent_core-2.1.so.7.0.1" )

# Import target "libevent::extra" for configuration "None"
set_property(TARGET libevent::extra APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(libevent::extra PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib32/libevent_extra-2.1.so.7.0.1"
  IMPORTED_SONAME_NONE "libevent_extra-2.1.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS libevent::extra )
list(APPEND _IMPORT_CHECK_FILES_FOR_libevent::extra "${_IMPORT_PREFIX}/lib32/libevent_extra-2.1.so.7.0.1" )

# Import target "libevent::openssl" for configuration "None"
set_property(TARGET libevent::openssl APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(libevent::openssl PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib32/libevent_openssl-2.1.so.7.0.1"
  IMPORTED_SONAME_NONE "libevent_openssl-2.1.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS libevent::openssl )
list(APPEND _IMPORT_CHECK_FILES_FOR_libevent::openssl "${_IMPORT_PREFIX}/lib32/libevent_openssl-2.1.so.7.0.1" )

# Import target "libevent::pthreads" for configuration "None"
set_property(TARGET libevent::pthreads APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(libevent::pthreads PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib32/libevent_pthreads-2.1.so.7.0.1"
  IMPORTED_SONAME_NONE "libevent_pthreads-2.1.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS libevent::pthreads )
list(APPEND _IMPORT_CHECK_FILES_FOR_libevent::pthreads "${_IMPORT_PREFIX}/lib32/libevent_pthreads-2.1.so.7.0.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> lib32-libevent-2.1.12-4-x86_64.pkg.tar.zst: usr/lib32/cmake/libevent/LibeventTargets-shared-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "libevent::core" for configuration "None"
set_property(TARGET libevent::core APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(libevent::core PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib32/libevent_core-2.1.so.7.0.1"
  IMPORTED_SONAME_NONE "libevent_core-2.1.so.7"
  )

list(APPEND _cmake_import_check_targets libevent::core )
list(APPEND _cmake_import_check_files_for_libevent::core "${_IMPORT_PREFIX}/lib32/libevent_core-2.1.so.7.0.1" )

# Import target "libevent::extra" for configuration "None"
set_property(TARGET libevent::extra APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(libevent::extra PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib32/libevent_extra-2.1.so.7.0.1"
  IMPORTED_SONAME_NONE "libevent_extra-2.1.so.7"
  )

list(APPEND _cmake_import_check_targets libevent::extra )
list(APPEND _cmake_import_check_files_for_libevent::extra "${_IMPORT_PREFIX}/lib32/libevent_extra-2.1.so.7.0.1" )

# Import target "libevent::openssl" for configuration "None"
set_property(TARGET libevent::openssl APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(libevent::openssl PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib32/libevent_openssl-2.1.so.7.0.1"
  IMPORTED_SONAME_NONE "libevent_openssl-2.1.so.7"
  )

list(APPEND _cmake_import_check_targets libevent::openssl )
list(APPEND _cmake_import_check_files_for_libevent::openssl "${_IMPORT_PREFIX}/lib32/libevent_openssl-2.1.so.7.0.1" )

# Import target "libevent::pthreads" for configuration "None"
set_property(TARGET libevent::pthreads APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(libevent::pthreads PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib32/libevent_pthreads-2.1.so.7.0.1"
  IMPORTED_SONAME_NONE "libevent_pthreads-2.1.so.7"
  )

list(APPEND _cmake_import_check_targets libevent::pthreads )
list(APPEND _cmake_import_check_files_for_libevent::pthreads "${_IMPORT_PREFIX}/lib32/libevent_pthreads-2.1.so.7.0.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
